@@ -21,10 +21,10 @@ const (
 	_GotoLine
 )
 
-type StatusBarStyle int
+type StatusBarOption int
 
 const (
-	STATUSBAR_STYLE_INVERSE StatusBarStyle = iota
+	STATUSBAR_STYLE_INVERSE StatusBarOption = iota
 	STATUSBAR_STYLE_PLAIN
 	STATUSBAR_STYLE_BOLD
 )
@@ -37,6 +37,8 @@ const (
 	UNPRINTABLE_STYLE_WHITESPACE
 )
 
+var unprintableStyle UnprintableStyle
+
 type eventSpinnerUpdate struct {
 	spinner string
 }
@@ -47,9 +49,6 @@ type eventMoreLinesAvailable struct{}
 // reader.HighlightingDone() for details.
 type eventMaybeDone struct{}
 
-// Styling of line numbers
-var _numberStyle = twin.StyleDefault.WithAttr(twin.AttrDim)
-
 // Pager is the main on-screen pager
 type Pager struct {
 	reader              *Reader
@@ -72,7 +71,7 @@ type Pager struct {
 	// NewPager shows lines by default, this field can hide them
 	ShowLineNumbers bool
 
-	StatusBarStyle StatusBarStyle
+	StatusBarStyle StatusBarOption
 	ShowStatusBar  bool
 
 	UnprintableStyle UnprintableStyle
@@ -96,15 +95,13 @@ type Pager struct {
 	// clear the last line, and show the cursor.
 	DeInit bool
 
-	// Render the UI using this style
-	ChromaStyle *chroma.Style
-
-	// Render the UI using this formatter
-	ChromaFormatter *chroma.Formatter
-
 	// Optional ANSI to prefix each text line with. Initialised using
-	// ChromaStyle and ChromaFormatter.
+	// ChromaStyle and ChromaFormatter. Used for coloring unstyled text lines
+	// based on the Chroma style.
 	linePrefix string
+
+	// Length of the longest line displayed. This is used for limiting scrolling to the right.
+	longestLineLength int
 }
 
 type _PreHelpState struct {
@@ -205,25 +202,13 @@ func (p *Pager) setFooter(footer string) {
 	width, height := p.screen.Size()
 
 	pos := 0
-	var footerStyle twin.Style
-	if standoutStyle != nil {
-		footerStyle = *standoutStyle
-	} else if p.StatusBarStyle == STATUSBAR_STYLE_INVERSE {
-		footerStyle = twin.StyleDefault.WithAttr(twin.AttrReverse)
-	} else if p.StatusBarStyle == STATUSBAR_STYLE_PLAIN {
-		footerStyle = twin.StyleDefault
-	} else if p.StatusBarStyle == STATUSBAR_STYLE_BOLD {
-		footerStyle = twin.StyleDefault.WithAttr(twin.AttrBold)
-	} else {
-		panic(fmt.Sprint("Unrecognized footer style: ", footerStyle))
-	}
 	for _, token := range footer {
-		p.screen.SetCell(pos, height-1, twin.NewCell(token, footerStyle))
+		p.screen.SetCell(pos, height-1, twin.NewCell(token, statusbarStyle))
 		pos++
 	}
 
 	for ; pos < width; pos++ {
-		p.screen.SetCell(pos, height-1, twin.NewCell(' ', footerStyle))
+		p.screen.SetCell(pos, height-1, twin.NewCell(' ', statusbarStyle))
 	}
 }
 
@@ -261,6 +246,12 @@ func (p *Pager) moveRight(delta int) {
 	} else {
 		p.leftColumnZeroBased = result
 	}
+
+	// If we try to move past the characters when moving right, stop scrolling to
+	// avoid moving infinitely into the void.
+	if p.leftColumnZeroBased > p.longestLineLength {
+		p.leftColumnZeroBased = p.longestLineLength
+	}
 }
 
 func (p *Pager) handleScrolledUp() {
@@ -444,22 +435,18 @@ func (p *Pager) onRune(char rune) {
 	}
 }
 
-func (p *Pager) initStyle() {
-	if p.ChromaStyle == nil && p.ChromaFormatter == nil {
-		return
+// Return an ANSI SGR sequence to use for plain text. Can be "".
+func getLineColorPrefix(chromaStyle *chroma.Style, chromaFormatter *chroma.Formatter) string {
+	if chromaStyle == nil && chromaFormatter == nil {
+		return ""
 	}
-	if p.ChromaStyle == nil || p.ChromaFormatter == nil {
+	if chromaStyle == nil || chromaFormatter == nil {
 		panic("Both ChromaStyle and ChromaFormatter should be set or neither")
 	}
 
 	stringBuilder := strings.Builder{}
-	err := (*p.ChromaFormatter).Format(&stringBuilder, p.ChromaStyle, chroma.Literator(chroma.Token{
-		// FIXME: They Type here should really be None. "Background" is a
-		// workaround until we can bump Chroma to a release with this change in
-		// it:
-		// https://github.com/alecthomas/chroma/pull/869
-		Type: chroma.Background,
-
+	err := (*chromaFormatter).Format(&stringBuilder, chromaStyle, chroma.Literator(chroma.Token{
+		Type:  chroma.None,
 		Value: "XXX",
 	}))
 	if err != nil {
@@ -472,11 +459,11 @@ func (p *Pager) initStyle() {
 		panic("XXX not found in " + formatted)
 	}
 
-	p.linePrefix = formatted[:cutoff]
+	return formatted[:cutoff]
 }
 
 // StartPaging brings up the pager on screen
-func (p *Pager) StartPaging(screen twin.Screen) {
+func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chromaFormatter *chroma.Formatter) {
 	log.Trace("Pager starting")
 	defer log.Trace("Pager done")
 
@@ -487,10 +474,11 @@ func (p *Pager) StartPaging(screen twin.Screen) {
 	}()
 
 	unprintableStyle = p.UnprintableStyle
-	ConsumeLessTermcapEnvs()
+	consumeLessTermcapEnvs(chromaStyle, chromaFormatter)
+	styleUi(chromaStyle, chromaFormatter, p.StatusBarStyle)
 
 	p.screen = screen
-	p.initStyle()
+	p.linePrefix = getLineColorPrefix(chromaStyle, chromaFormatter)
 
 	go func() {
 		for range p.reader.moreLinesAdded {
