@@ -25,6 +25,19 @@ import (
 
 var versionString = "Should be set when building, please use build.sh to build"
 
+func printUsageEnvVar(output io.Writer, envVarName string, description string) {
+	value := os.Getenv(envVarName)
+	if len(value) == 0 {
+		return
+	}
+
+	_, _ = fmt.Fprintf(output, "  %s (%s): %s\n",
+		envVarName,
+		description,
+		strings.ReplaceAll(value, "\x1b", "ESC"),
+	)
+}
+
 func printUsage(output io.Writer, flagSet *flag.FlagSet, printCommandline bool) {
 	// This controls where PrintDefaults() prints, see below
 	flagSet.SetOutput(output)
@@ -58,6 +71,10 @@ func printUsage(output io.Writer, flagSet *flag.FlagSet, printCommandline bool)
 		_, _ = fmt.Fprintf(output, "  Current setting: MOAR=\"%s\"\n", moarEnv)
 	}
 
+	printUsageEnvVar(output, "LESS_TERMCAP_md", "man page bold style")
+	printUsageEnvVar(output, "LESS_TERMCAP_us", "man page underline style")
+	printUsageEnvVar(output, "LESS_TERMCAP_so", "search hits and footer style")
+
 	absMoarPath, err := absLookPath(os.Args[0])
 	if err == nil {
 		absPagerValue, err := absLookPath(os.Getenv("PAGER"))
@@ -149,7 +166,7 @@ func parseStyleOption(styleOption string) (chroma.Style, error) {
 	return *style, nil
 }
 
-func parseColorsOption(colorsOption string) (chroma.Formatter, error) {
+func parseColorsOption(colorsOption string) (twin.ColorType, error) {
 	if strings.ToLower(colorsOption) == "auto" {
 		colorsOption = "16M"
 		if strings.Contains(os.Getenv("TERM"), "256") {
@@ -160,19 +177,20 @@ func parseColorsOption(colorsOption string) (chroma.Formatter, error) {
 
 	switch strings.ToUpper(colorsOption) {
 	case "8":
-		return formatters.TTY8, nil
+		return twin.ColorType8, nil
 	case "16":
-		return formatters.TTY16, nil
+		return twin.ColorType16, nil
 	case "256":
-		return formatters.TTY256, nil
+		return twin.ColorType256, nil
 	case "16M":
-		return formatters.TTY16m, nil
+		return twin.ColorType24bit, nil
 	}
 
-	return nil, fmt.Errorf("Valid counts are 8, 16, 256, 16M or auto.")
+	var noColor twin.ColorType
+	return noColor, fmt.Errorf("Valid counts are 8, 16, 256, 16M or auto.")
 }
 
-func parseStatusBarStyle(styleOption string) (m.StatusBarStyle, error) {
+func parseStatusBarStyle(styleOption string) (m.StatusBarOption, error) {
 	if styleOption == "inverse" {
 		return m.STATUSBAR_STYLE_INVERSE, nil
 	}
@@ -227,13 +245,13 @@ func parseMouseMode(mouseMode string) (twin.MouseMode, error) {
 	switch mouseMode {
 	case "auto":
 		return twin.MouseModeAuto, nil
-	case "mark":
-		return twin.MouseModeMark, nil
+	case "select", "mark":
+		return twin.MouseModeSelect, nil
 	case "scroll":
 		return twin.MouseModeScroll, nil
 	}
 
-	return twin.MouseModeAuto, fmt.Errorf("Valid modes are auto, mark and scroll")
+	return twin.MouseModeAuto, fmt.Errorf("Valid modes are auto, select and scroll")
 }
 
 func pumpToStdout(inputFilename *string) error {
@@ -368,7 +386,7 @@ func main() {
 	if err != nil {
 		panic(fmt.Errorf("Failed parsing default formatter: %w", err))
 	}
-	formatter := flagSetFunc(flagSet,
+	terminalColorsCount := flagSetFunc(flagSet,
 		"colors", defaultFormatter, "Highlighting palette size: 8, 16, 256, 16M, auto", parseColorsOption)
 
 	noLineNumbers := flagSet.Bool("no-linenumbers", false, "Hide line numbers on startup, press left arrow key to show")
@@ -390,7 +408,7 @@ func main() {
 		flagSet,
 		"mousemode",
 		twin.MouseModeAuto,
-		"Mouse mode: auto, mark or scroll: https://github.com/walles/moar/blob/master/MOUSE.md",
+		"Mouse mode: auto, select or scroll: https://github.com/walles/moar/blob/master/MOUSE.md",
 		parseMouseMode,
 	)
 
@@ -482,7 +500,7 @@ func main() {
 		panic("Invariant broken: stdout is not a terminal")
 	}
 
-	screen, err := twin.NewScreenWithMouseMode(*mouseMode)
+	screen, err := twin.NewScreenWithMouseModeAndColorType(*mouseMode, *terminalColorsCount)
 	if err != nil {
 		// Ref: https://github.com/walles/moar/issues/149
 		log.Debug("Failed to set up screen for paging, pumping to stdout instead: ", err)
@@ -494,13 +512,22 @@ func main() {
 		return
 	}
 
+	formatter := formatters.TTY256
+	if *terminalColorsCount == twin.ColorType8 {
+		formatter = formatters.TTY8
+	} else if *terminalColorsCount == twin.ColorType16 {
+		formatter = formatters.TTY16
+	} else if *terminalColorsCount == twin.ColorType24bit {
+		formatter = formatters.TTY
+	}
+
 	var reader *m.Reader
 	if stdinIsRedirected {
 		// Display input pipe contents
 		reader = m.NewReaderFromStream("", os.Stdin)
 	} else {
 		// Display the input file contents
-		reader, err = m.NewReaderFromFilename(*inputFilename, *style, *formatter)
+		reader, err = m.NewReaderFromFilename(*inputFilename, *style, formatter)
 		if err != nil {
 			fmt.Fprintf(os.Stderr, "ERROR: %v\n", err)
 			os.Exit(1)
@@ -518,15 +545,13 @@ func main() {
 	pager.ScrollLeftHint = *scrollLeftHint
 	pager.ScrollRightHint = *scrollRightHint
 	pager.SideScrollAmount = int(*shift)
-	pager.ChromaStyle = style
-	pager.ChromaFormatter = formatter
 
 	pager.TargetLineNumberOneBased = targetLineNumberOneBased
 	if *follow && pager.TargetLineNumberOneBased == 0 {
 		pager.TargetLineNumberOneBased = math.MaxInt
 	}
 
-	startPaging(pager, screen)
+	startPaging(pager, screen, style, &formatter)
 }
 
 // Define a generic flag with specified name, default value, and usage string.
@@ -547,7 +572,7 @@ func flagSetFunc[T any](flagSet *flag.FlagSet, name string, defaultValue T, usag
 	return &parsed
 }
 
-func startPaging(pager *m.Pager, screen twin.Screen) {
+func startPaging(pager *m.Pager, screen twin.Screen, chromaStyle *chroma.Style, chromaFormatter *chroma.Formatter) {
 	defer func() {
 		// Restore screen...
 		screen.Close()
@@ -566,5 +591,5 @@ func startPaging(pager *m.Pager, screen twin.Screen) {
 		}
 	}()
 
-	pager.StartPaging(screen)
+	pager.StartPaging(screen, chromaStyle, chromaFormatter)
 }
